CStatelessMaterialPage<P extends PagePath, R> class abstract

Inheritance

Constructors

CStatelessMaterialPage({required ValueKey<String> key, required Widget child, String? factoryKey, P? path})

Properties

allowSnapshotting bool
Whether the route transition will prefer to animate a snapshot of the entering/exiting routes.
finalinherited
arguments Object?
The arguments passed to this route.
finalinherited
canPop bool
When false, blocks the associated route from being popped.
finalinherited
child Widget
The content to be shown in the Route created by this page.
finalinherited
completer Completer<R?>
finalinherited
fullscreenDialog bool
Whether this page route is a full-screen dialog.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
no setterinherited
key ValueKey<String>?
The key associated with this page.
no setterinherited
maintainState bool
Whether the route should remain in memory when it is inactive.
finalinherited
name String?
The name of the route (e.g., "/settings").
finalinherited
onPopInvoked PopInvokedWithResultCallback
Called after a pop on the associated route was handled.
finalinherited
path → P?
final
restorationId String?
Restoration ID to save and restore the state of the Route configured by this page.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state PPageStateMixin<P, R>?
no setterinherited

Methods

canUpdate(Page other) bool
Whether this page can be updated with the other page.
inherited
createPopEvent({required R? data, required PopCause cause}) PagePopEvent<R>
Creates PagePopEvent.
inherited
createRoute(BuildContext context) Route
Creates the Route that corresponds to this page.
inherited
dispose() → void
inherited
getFactoryKey() String?
The key to re-create this page with factory when recovering state.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited